import type { Context, DynamoDBBatchResponse, DynamoDBRecord, DynamoDBStreamEvent } from 'aws-lambda';
import Transaction, { TransactionConfig } from './Transaction.js';
import Response, { ResponseErrorType } from '../API/Response.js';
export interface DynamoDBMarshalledRecord extends DynamoDBRecord {
    marshalled: {
        Keys?: object;
        OldImage?: object;
        NewImage?: object;
    };
}
export type DynamoTransactionExecution<ResponseInnerType> = (transaction: Transaction<null, ResponseInnerType | ResponseErrorType, DynamoDBBatchResponse | null>, recordContent: DynamoDBMarshalledRecord) => Promise<Response<ResponseInnerType | ResponseErrorType> | DynamoDBBatchResponse | null>;
export default class DynamoTransaction<ResponseInnerType> {
    private readonly allowFailure;
    private readonly config;
    private readonly context;
    private readonly event;
    constructor(event: DynamoDBStreamEvent, context: Context, config?: TransactionConfig, allowFailure?: boolean);
    processEvent(execution: DynamoTransactionExecution<ResponseInnerType>): Promise<Response<ResponseErrorType | null> | null | DynamoDBBatchResponse>;
    private processRawEvent;
}
