var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Transaction from './Transaction.js';
import Response from '../API/Response.js';
import Globals from '../Globals.js';
import Utils from '../Util/Utils.js';
export default class DynamoTransaction {
    constructor(event, context, config, allowFailure) {
        this.event = event;
        this.context = context;
        this.config = config || {};
        this.allowFailure = !!allowFailure;
    }
    processEvent(execution) {
        return __awaiter(this, void 0, void 0, function* () {
            const resp = yield this.processRawEvent(execution);
            if (!this.allowFailure &&
                resp &&
                resp instanceof Response &&
                !(resp.getCode() >= 200 && resp.getCode() < 300))
                throw new Error(JSON.stringify(resp.getBody() || {}));
            else if (resp)
                return resp;
            return null;
        });
    }
    processRawEvent(execution) {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            // safe check for empty events?
            if (this.event.Records && this.event.Records.length > 0) {
                // Regular cleanup of tmp disk to avoid tmp overflow on reused lambdas
                if (!((_a = this.config) === null || _a === void 0 ? void 0 : _a.skipCleanTmp))
                    yield Utils.cleanTemporaryFolder();
                // init transaction for all records
                return yield new Transaction(this.event, this.context, Object.assign(Object.assign({}, this.config), { syncReturn: true })).execute((transaction) => __awaiter(this, void 0, void 0, function* () {
                    var _a, _b, _c, _d, _e, _f;
                    // for each available event
                    const failureIDs = [];
                    for (const eventRecordIdx in this.event.Records) {
                        const eventRecord = this.event.Records[eventRecordIdx];
                        const record = Object.assign(Object.assign({}, eventRecord), { marshalled: Object.assign(Object.assign(Object.assign({}, (((_a = eventRecord.dynamodb) === null || _a === void 0 ? void 0 : _a.Keys)
                                ? { Keys: Utils.ddbUnmarshall((_b = eventRecord.dynamodb) === null || _b === void 0 ? void 0 : _b.Keys) }
                                : {})), (((_c = eventRecord.dynamodb) === null || _c === void 0 ? void 0 : _c.OldImage)
                                ? { OldImage: Utils.ddbUnmarshall((_d = eventRecord.dynamodb) === null || _d === void 0 ? void 0 : _d.OldImage) }
                                : {})), (((_e = eventRecord.dynamodb) === null || _e === void 0 ? void 0 : _e.NewImage)
                                ? { NewImage: Utils.ddbUnmarshall((_f = eventRecord.dynamodb) === null || _f === void 0 ? void 0 : _f.NewImage) }
                                : {})) });
                        // Call execution with marshalled item
                        const resp = yield execution(transaction, record);
                        // check for failure
                        if (!resp ||
                            (resp instanceof Response && !((resp === null || resp === void 0 ? void 0 : resp.getCode()) >= 200 && (resp === null || resp === void 0 ? void 0 : resp.getCode()) < 300))) {
                            // response with failures or fail hard at first
                            if (this.allowFailure)
                                failureIDs.push(eventRecord.eventID);
                            else
                                return resp;
                        }
                    }
                    // not errored and loop ended - succeeded (might have failures)
                    if (this.allowFailure)
                        return {
                            batchItemFailures: failureIDs.map(id => ({ itemIdentifier: id })),
                        };
                    return Response.SuccessResponse(null);
                }));
            }
            else
                return Response.BadRequestResponse(Globals.ErrorResponseNoRecords, Globals.ErrorCode_NoRecords);
        });
    }
}
//# sourceMappingURL=DynamoTransaction.js.map