var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Logger from '../Logger/Logger.js';
import Publisher from '../Publisher/Publisher.js';
/**
 * Represents a long-running process that executes a given function at a specified interval.
 */
export default class Process {
    /**
     * Constructs a new instance of the LongRunningProcess class.
     * @param {ProcessConfig} config - The configuration object for the process.
     * @param {number} interval - The interval at which the process should run.
     * @returns None
     */
    constructor(config, interval) {
        this.interval = interval;
        this.logger = new Logger(config.logger, 'long-running-process');
        this.publisher = new Publisher(config.publisher);
    }
    /**
     * Executes the provided execution function at a specified interval.
     * @param {Function} executionFunc - The function to execute.
     * @returns None
     */
    execute(executionFunc) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger.debug('Starting main process code');
            //Program loop
            this.timeout = setInterval(() => __awaiter(this, void 0, void 0, function* () {
                yield this.iexecute(executionFunc);
            }), this.interval);
        });
    }
    /**
     * Executes the given execution function asynchronously and handles any exceptions that occur.
     * @param {Function} executionFunc - The function to execute.
     * @returns {boolean} - Returns true if the execution failed, false otherwise.
     */
    iexecute(executionFunc) {
        return __awaiter(this, void 0, void 0, function* () {
            let executionFailed = true; //failed til we say no!
            // safe execution handler
            try {
                // Execute
                yield executionFunc(this);
                executionFailed = false;
            }
            catch (e) {
                /* EXECUTION FAIL */
                this.logger.error('Exception when executing main process code. Rolling back DB!');
                this.logger.exception(e);
            }
            return executionFailed;
        });
    }
}
//# sourceMappingURL=Process.js.map