import Transaction from './Transaction.js';
import Response from '../API/Response.js';
/**
 * Represents a step transaction that extends the Transaction class.
 */
export default class StepTransaction extends Transaction {
    /**
     * Constructor for creating a new Transaction object.
     * @param {any} event - The event object.
     * @param {Context} context - The context object.
     * @param {TransactionConfig} [config] - Optional configuration for the transaction.
     * @returns None
     */
    constructor(event, context, config) {
        super(event, context, Object.assign({ syncReturn: true, throwOnErrors: true }, (config || {})));
    }
    /**
     * Generates an error response with the provided error message and error code.
     * @param {string} error - The error message to include in the response.
     * @param {string} code - The error code associated with the error.
     * @returns {Response<ResponseErrorType>} - The error response object.
     */
    getErrorResponse(error, code) {
        return Response.StepFunctionResponse({ err: error, errCode: code }, 400);
    }
}
//# sourceMappingURL=StepTransaction.js.map