var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var _a;
import { createCluster, createClient } from 'redis';
import AsyncSingleton from '../Util/AsyncSingleton.js';
/**
 * Represents a Redis cache connection class.
 */
class Redis {
    static connection(config) {
        return _a.singleton.instance(config);
    }
    static connectionFactory(config) {
        return __awaiter(this, void 0, void 0, function* () {
            if (config.clusterMode)
                return _a.redisClusterConnection(config);
            else
                return _a.redisClientConnection(config);
        });
    }
    /**
     * Establishes a connection to a Redis client based on the provided configuration
     * and holds it for reusability. If connection is detected closed, new connection is
     * initialized and established.
     * @param {CacheConfig<'redis'>} config - The configuration object for connecting to the Redis client.
     * @returns {Promise<RedisClientType>} A promise that resolves to the Redis client connection.
     */
    static redisClientConnection(config) {
        return __awaiter(this, void 0, void 0, function* () {
            console.debug('Starting remote client cache connection');
            const connection = _a.ClientFactory(Object.assign(Object.assign({ username: config.username }, (config.password ? { password: config.password } : {})), { disableOfflineQueue: true, socket: {
                    host: config.hostname,
                    tls: config.enableTLS,
                    connectTimeout: 10000,
                } }));
            yield connection.connect();
            return connection;
        });
    }
    static redisClusterConnection(config) {
        return __awaiter(this, void 0, void 0, function* () {
            console.debug('Starting remote cluster cache connection');
            const connection = _a.ClusterFactory({
                defaults: Object.assign(Object.assign({ username: config.username }, (config.password ? { password: config.password } : {})), { socket: {
                        tls: config.enableTLS,
                        connectTimeout: 10000,
                    } }),
                rootNodes: [
                    {
                        url: `redis://${config.username}:${config.username}@${config.hostname}:6379`,
                        disableOfflineQueue: true,
                    },
                ],
            });
            yield connection.connect();
            return connection;
        });
    }
}
_a = Redis;
Redis.singleton = new AsyncSingleton(_a.connectionFactory, (c) => __awaiter(void 0, void 0, void 0, function* () { return c.isOpen; }));
/**
 * A private static property that holds a reference to the redis.createClient function.
 * This property is used to create client.
 */
Redis.ClientFactory = createClient;
/**
 * A private static property that references the createCluster function.
 * This property can be used to create clusters within the class.
 */
Redis.ClusterFactory = createCluster;
export default Redis;
//# sourceMappingURL=Redis.js.map