import { DynamoDBClient } from '@aws-sdk/client-dynamodb';
import { Database } from '../../Database.js';
import type { DbConfig } from '../../types.js';
/**
 * Represents a DynamoDB database connection that extends a generic Database class.
 * @extends Database<any>
 */
export declare class DynamoDatabase extends Database<any> {
    /**
     * A private static property that holds an instance of the DynamoDBClient class.
     * This property can be used to interact with DynamoDB services.
     */
    private static dynamoProvider;
    /**
     * A readonly property representing the DynamoDB client used to interact with DynamoDB.
     */
    readonly client: DynamoDBClient;
    /**
     * Constructor for creating a new instance of a class that interacts with a DynamoDB database.
     * @param {DbConfig<'dynamo'>} config - The configuration object for DynamoDB.
     * @returns None
     */
    constructor(config: DbConfig<'dynamo'>);
    /**
     * Override method to handle a transaction asynchronously.
     * @returns A Promise that resolves to null.
     */
    transaction(): Promise<any>;
    /**
     * Creates a provider for DynamoDB based on the provided configuration.
     * @param {DbConfig<'dynamo'>} config - The configuration object for DynamoDB.
     * @returns A DynamoDB provider instance based on the provided configuration.
     */
    private providerFactory;
}
