var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { Agent } from 'https';
import { DynamoDBClient } from '@aws-sdk/client-dynamodb';
import { NodeHttpHandler } from '@smithy/node-http-handler';
import { Database } from '../../Database.js';
/**
 * Represents a DynamoDB database connection that extends a generic Database class.
 * @extends Database<any>
 */
export class DynamoDatabase extends Database {
    /**
     * Constructor for creating a new instance of a class that interacts with a DynamoDB database.
     * @param {DbConfig<'dynamo'>} config - The configuration object for DynamoDB.
     * @returns None
     */
    constructor(config) {
        super(config);
        this.client = this.providerFactory(config);
    }
    /**
     * Override method to handle a transaction asynchronously.
     * @returns A Promise that resolves to null.
     */
    transaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return Promise.resolve(null);
        });
    }
    /**
     * Creates a provider for DynamoDB based on the provided configuration.
     * @param {DbConfig<'dynamo'>} config - The configuration object for DynamoDB.
     * @returns A DynamoDB provider instance based on the provided configuration.
     */
    providerFactory(config) {
        return new DynamoDatabase.dynamoProvider({
            region: config.region,
            maxAttempts: config.maxAttempts || 3,
            requestHandler: new NodeHttpHandler({
                connectionTimeout: config.connectionTimeout || 60000,
                socketTimeout: config.connectionTimeout || 60000,
                httpsAgent: new Agent({ keepAlive: false, maxSockets: 50, rejectUnauthorized: true }),
            }),
        });
    }
}
/**
 * A private static property that holds an instance of the DynamoDBClient class.
 * This property can be used to interact with DynamoDB services.
 */
DynamoDatabase.dynamoProvider = DynamoDBClient;
//# sourceMappingURL=DynamoDatabase.js.map