var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import pg from 'pg';
import { PostgresTransactionImpl } from './PostgresTransaction.js';
import { Database } from '../../Database.js';
/**
 * Represents a Postgres database connection that extends the Database class.
 * @extends Database<PostgresTransaction>
 */
export class PostgresDatabase extends Database {
    /**
     * Constructor for creating a new instance of a database connection using Postgres.
     * @param {DbConfig<'pg'>} config - The configuration object for the Postgres database.
     * @returns None
     */
    constructor(config) {
        super(config);
        this.client = this.providerFactory(config);
        if (config.readReplica)
            this.readClient = this.providerFactory(config.readReplica);
    }
    /**
     * Creates a new Postgres transaction using the provided client and read client.
     * @returns {Promise<PostgresTransaction>} A promise that resolves to a new PostgresTransaction object.
     */
    transaction() {
        return __awaiter(this, void 0, void 0, function* () {
            return PostgresTransactionImpl.newTransaction(this.client, this, this.readClient);
        });
    }
    providerFactory(config) {
        return new PostgresDatabase.pgProvider({
            host: config.host,
            port: config.port,
            user: config.username,
            password: config.password,
            database: config.database,
            max: config.maxConnections,
        });
    }
}
/**
 * A public static property that represents a connection pool for a PostgreSQL database.
 * This property is used to manage and provide connections to the PostgreSQL database.
 */
PostgresDatabase.pgProvider = pg.Pool;
//# sourceMappingURL=PostgresDatabase.js.map