/**
 * Class containing global constants and configurations for the application.
 */
export default class Globals {
    /**
     * A constant string representing an error message for input validation failure.
     */
    static ErrorResponseValidationFail: string;
    /**
     * A constant string representing an error response for an invalid server response.
     */
    static ErrorResponseInvalidServerResponse: string;
    /**
     * The error message for an unhandled error when processing a request.
     */
    static ErrorResponseUnhandledError: string;
    /**
     * A static string representing an error response when there are no records to be processed.
     */
    static ErrorResponseNoRecords: string;
    /**
     * Represents an error code for a missing parameter.
     * @type {string}
     */
    static ErrorCode_MissingParam: string;
    /**
     * Represents an error code for invalid input.
     * @type {string}
     */
    static ErrorCode_InvalidInput: string;
    /**
     * Represents an error code for an API error.
     * @type {string}
     */
    static ErrorCode_APIError: string;
    /**
     * Represents the error code for when there are no records found.
     * @type {string}
     */
    static ErrorCode_NoRecords: string;
    /**
     * Retrieves the default port number for HTTP listeners.
     * The port number is obtained from the environment variable "PORT" and parsed as an integer.
     * If the environment variable is not set or cannot be parsed as an integer, the default port number 9000 is used.
     * @returns {number} - The default port number for HTTP listeners.
     */
    static Listener_HTTP_DefaultPort: number;
    /**
     * The default host for the HTTP listener.
     */
    static Listener_HTTP_DefaultHost: string;
    /**
     * The HTTP proxy route listener for all routes.
     * @type {string}
     */
    static Listener_HTTP_ProxyRoute: string;
    /**
     * Retrieves the default timeout value for HTTP listeners.
     * @returns {number} The default timeout value in milliseconds.
     */
    static Listener_HTTP_DefaultTimeout: number;
    /**
     * The default health check route for the HTTP listener.
     * @type {string}
     */
    static Listener_HTTP_DefaultHealthCheckRoute: string;
    /**
     * The response message for an exception that occurred during request execution in the Proxy.
     */
    static Resp_MSG_EXCEPTION: string;
    /**
     * The response code for an exception that occurred during execution.
     */
    static Resp_CODE_EXCEPTION: string;
    /**
     * The HTTP response status code for an exception scenario.
     */
    static Resp_STATUSCODE_EXCEPTION: number;
    /**
     * The error message for an invalid response from the server.
     */
    static Resp_MSG_INVALIDRESP: string;
    /**
     * Represents the response code for an invalid response.
     */
    static Resp_CODE_INVALIDRESP: string;
    /**
     * The HTTP response status code for an invalid response.
     * @type {number}
     * @default 400
     */
    static Resp_STATUSCODE_INVALIDRESP: number;
}
