var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { SNSClient, PublishCommand, } from '@aws-sdk/client-sns';
import sha1 from 'sha1';
//reusable client
/**
 * A variable that holds the connection to the SNS client for publishing messages.
 * @type {SNSClient | null}
 */
// eslint-disable-next-line no-var
let PUBLISHER_CONN = null;
/**
 * The connection hash for the publisher. It is initially set to null.
 * @type {string | null}
 */
// eslint-disable-next-line no-var
let PUBLISHER_CONN_HASH = null;
/**
 * Represents a publisher that can publish messages to an SNS topic.
 */
export default class Publisher {
    /**
     * Constructs a new instance of the Publisher class.
     * @param {PublisherConfig} [config] - The configuration object for the Publisher.
     * @returns None
     */
    constructor(config) {
        if (config && config.region) {
            this.region = config.region;
            // console.debug(`Using region: ${this.region}`);
        }
    }
    /**
     * Publishes a message on a specified topic.
     * @param {any} messageObject - The message object to be published.
     * @param {string} topic - The ARN of the topic to publish the message to.
     * @param {object} [additionalProps] - Additional properties to include in the publish command.
     * @returns {Promise<PublishCommandOutput>} - A promise that resolves to the response from the publish command.
     */
    publishOnTopic(messageObject, topic, additionalProps) {
        return __awaiter(this, void 0, void 0, function* () {
            let resp = undefined;
            try {
                this.connect();
                //Send to SNS
                const params = Object.assign({ Message: JSON.stringify(messageObject), TopicArn: topic }, (additionalProps ? additionalProps : {}));
                resp = yield PUBLISHER_CONN.send(new PublishCommand(params));
            }
            catch (e) {
                console.error(`Error while publishing into topic ${topic} with error: ${e}`);
            }
            console.debug('Publisher resp', resp);
            return resp;
        });
    }
    /**
     * Establishes a connection to the SNS client if it does not already exist or if the region has changed.
     * @returns None
     */
    connect() {
        if ((!PUBLISHER_CONN && !PUBLISHER_CONN_HASH) || PUBLISHER_CONN_HASH != sha1(this.region)) {
            PUBLISHER_CONN = new SNSClient({
                apiVersion: '2010-03-31',
                region: this.region,
            });
            PUBLISHER_CONN_HASH = sha1(this.region).toString();
        }
    }
}
//# sourceMappingURL=Publisher.js.map