import ContainerServer from './lib/ContainerServer.js';
import Server from './lib/Server.js';
import Utils from '../Util/Utils.js';
/**
 * Represents a router that handles routing logic for a web application.
 */
export default class Router {
    /**
     * Constructs a new instance of the Router class.
     * @param {RouterConfig} config - The configuration object for the router.
     * @returns None
     */
    constructor(config) {
        this.config = config;
        this.server = this.isContainer() ? new ContainerServer(config) : new Server(config);
    }
    /**
     * Retrieves the export function from the server.
     * @returns {CallableFunction} The export function from the server.
     */
    getExport() {
        return this.server.getExport();
    }
    /**
     * Checks if the current element is a container.
     * @returns {boolean} - True if the element is a container, false otherwise.
     */
    isContainer() {
        return Utils.isHybridlessContainer();
    }
}
//# sourceMappingURL=Router.js.map