import Proxy from './container/Proxy.js';
import Server from './Server.js';
import { RouterConfig } from '../Router.js';
/**
 * Represents a server container that extends the Server class and handles serverless events.
 */
export default class ContainerServer extends Server {
    /**
     * The proxy object used for handling requests and responses.
     * @type {Proxy}
     * @protected
     */
    protected readonly proxy: Proxy;
    /**
     * Constructs a new instance of the Router class.
     * @param {RouterConfig} config - The configuration object for the router.
     * @returns None
     */
    constructor(config: RouterConfig);
    /**
     * Returns a callable function that can be used to export data.
     * @returns {CallableFunction} - A callable function that can be used to export data.
     */
    getExport(): CallableFunction;
    /**
     * Starts the application by loading the proxy.
     * @returns {Promise<void>} - A promise that resolves when the proxy is loaded.
     */
    start(): Promise<void>;
    /**
     * Stops the execution of the program and unloads the proxy.
     * @param {any} [err] - Optional error object to pass to the unload method.
     * @returns {Promise<void>} - A promise that resolves once the proxy is unloaded.
     */
    stop(err?: any): Promise<void>;
    /**
     * Listens for process events and handles them accordingly.
     * @private
     * @returns None
     */
    private listenProcessEvents;
}
