var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Proxy from './container/Proxy.js';
import Server from './Server.js';
/**
 * Represents a server container that extends the Server class and handles serverless events.
 */
export default class ContainerServer extends Server {
    /**
     * Constructs a new instance of the Router class.
     * @param {RouterConfig} config - The configuration object for the router.
     * @returns None
     */
    constructor(config) {
        super(config);
        this.proxy = new Proxy(config, this.handleServerlessEvent.bind(this));
        this.listenProcessEvents();
    }
    /**
     * Returns a callable function that can be used to export data.
     * @returns {CallableFunction} - A callable function that can be used to export data.
     */
    getExport() {
        // start server socket
        this.start();
        // return empty function, we are all done
        return () => { };
    }
    /**
     * Starts the application by loading the proxy.
     * @returns {Promise<void>} - A promise that resolves when the proxy is loaded.
     */
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.proxy.load();
        });
    }
    /**
     * Stops the execution of the program and unloads the proxy.
     * @param {any} [err] - Optional error object to pass to the unload method.
     * @returns {Promise<void>} - A promise that resolves once the proxy is unloaded.
     */
    stop(err) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.proxy.unload(err);
        });
    }
    /**
     * Listens for process events and handles them accordingly.
     * @private
     * @returns None
     */
    listenProcessEvents() {
        // start process listeners
        process.on('unhandledRejection', this.stop.bind(this)); // listen to exceptions
        process.on('SIGINT', this.stop.bind(this)); // listen on SIGINT signal and gracefully stop the server
    }
}
//# sourceMappingURL=ContainerServer.js.map