import { Context } from 'aws-lambda' // Import Context from aws-lambda

import Response from '../../src/API/Response.js'
import StepTransaction from '../../src/BaseEvent/StepTransaction.js'
import Transaction from '../../src/BaseEvent/Transaction.js'

describe('StepTransaction', () => {
  let mockEvent
  let mockContext

  beforeEach(() => {
    mockEvent = { key: 'value' }
    mockContext = {} as Context // Mock AWS Lambda context object
  })

  describe('constructor', () => {
    test('should create an instance of StepTransaction with default config', () => {
      const stepTransaction = new StepTransaction(mockEvent, mockContext)

      expect(stepTransaction).toBeInstanceOf(StepTransaction)
      expect(stepTransaction).toBeInstanceOf(Transaction)
      expect((stepTransaction as any).syncReturn).toBe(true)
      expect((stepTransaction as any).retrowErrors).toBe(true)
    })
  })

  describe('getErrorResponse', () => {
    test('should return an error response with provided error and code', () => {
      const stepTransaction = new StepTransaction(mockEvent, mockContext)
      const error = 'Test error message'
      const code = 'TestErrorCode'

      const response = (stepTransaction as any).getErrorResponse(error, code)

      expect(response).toBeInstanceOf(Response)
      expect(response).toEqual(
        expect.objectContaining({
          statusCode: 400,
          body: { err: error, errCode: code },
        })
      )
    })
  })
})
