import { SNSClient, PublishCommand } from '@aws-sdk/client-sns'
import { mockClient } from 'aws-sdk-client-mock'
import { expect } from 'chai'

import Publisher from '../../src/Publisher/Publisher.js'

const SNSMock = mockClient(SNSClient)

describe('SNS Pub-Sub', () => {
  // reset mock
  beforeEach(() => {
    SNSMock.reset()
  })

  const provider = new Publisher({
    region: 'ca-central-1',
  })

  test('Publishes with success', async () => {
    const msg = { text: '123' }
    const topic = '123'
    const messageId = 'id-123'
    SNSMock.on(PublishCommand, {
      Message: JSON.stringify(msg),
      TopicArn: topic,
    }).resolves({
      MessageId: messageId,
    })
    const res = await provider.publishOnTopic(msg, topic)
    expect(res).is.not.null
    expect(res?.MessageId).to.be.equals(messageId)
  })

  test('Publishes with success (additional props)', async () => {
    const msg = { text: '123' }
    const topic = '123'
    const messageId = 'id-123'
    SNSMock.on(PublishCommand, {
      Message: JSON.stringify(msg),
      TopicArn: topic,
    }).resolves({
      MessageId: messageId,
    })
    const res = await provider.publishOnTopic(msg, topic, {
      FifoGroup: 123,
    })
    expect(res).is.not.null
    expect(res?.MessageId).to.be.equals(messageId)
  })

  test('Publish failure', async () => {
    const msg = { text: '123' }
    const topic = '123'
    SNSMock.on(PublishCommand).rejects(new Error('failed!'))
    const res = await provider.publishOnTopic(msg, topic)
    expect(res).is.undefined
  })
})

export {}
